---
name: Feature request
about: Suggest an idea for this project
title: 'Description of the feature'
labels: enhancement
assignees: ''

---

## Purpose
<!--- A clear and concise description of the proposed new feature. -->

## Context
<!-- Why the new feature would be useful -->

## Possible Implementation (optional)
<!--- Not obligatory, but suggest an idea for implementing the new feature-->

## Related issues (optional)
<!-- Link any related issue-->
